@@ -6,7 +6,8 @@ from typing import Optional
 import requests
 from requests import Response
 
-from algora.api.service.auth.__util import _login_request_info, _refresh_token_request_info
+from algora.api.service.auth.__util import _login_request_info, _refresh_token_request_info, \
+    _token_exchange_request_info
 
 
 def login(username: str, password: str, scope: Optional[str] = None) -> Response:
@@ -39,3 +40,18 @@ def refresh_token(token: Optional[str]) -> Response:
     """
     request_info = _refresh_token_request_info(token)
     return requests.post(**request_info)
+
+
+def exchange_token(requested_subject: str, subject_token: str) -> Response:
+    """
+    Exchange token.
+
+    Args:
+        requested_subject (str): Request subject (Username or ID)
+        subject_token (str): Token to swap
+
+    Returns:
+        dict: Authentication/authorization response
+    """
+    request_info = _token_exchange_request_info(requested_subject, subject_token)
+    return requests.post(**request_info)
